/********************************************************************
 *   File:  FXOS8700.h					Date:  Dec 19, 2014
 *
 *   Definitions for the Freescale FXOS8700 6DOF (3-axis accelerometer and
 *   3-axis magnetometer) sensor used in the SOC Hand Sense system.
 *
 *   The PicoM305 is capable of communicating with 5 FXOS8700 FemtoB sensor
 *   chains consisting of three FXOS8700 sensors per chain for a total of
 *   15 sensors.  The PicoM305 has a four channel I2C channel multiplexor
 *   than compensates for the FXOS8700 limit of four unique I2C addresses per
 *   device.  Four FemtoB chains sit on I2C1 and a fifth chain on I2C2.
 *
 *   This project is licensed under the MIT license.  You can modify, enhance, etc anyway you like.
 *
 *   SOC Robotics, Inc is not liable in anyway for the use of this software and assumes no responsibility
 *   for it's use.  No warranties of any kind are provided.
 *
 *   Copyright 2014, SOC Robotics, Inc.
 *   There maybe code from other parties in this application  If we don't mention them by name thank you
 *   and if we should please let us know and we will include your name and attribution.
 */

//  FXOS8700 Acceleration Magnetometer Sensor defines
typedef struct
{
	short int xa,ya,za;
	short int xm,ym,zm;
} FXOSRawData;

typedef struct
{
	short int axi,ayi,azi;
	short int mxi,myi,mzi;
	float ax,ay,az;
	float mx,my,mz;
} FXOS_F;

// FXOS8700CQ I2C address
//#define FXOS8700CQ_SLAVE_ADDR 0x1E // with pins SA0=0, SA1=0
//#define FXOS8700CQ_SLAVE_ADDR 0x1D // with pins SA0=1, SA1=0
//#define FXOS8700CQ_SLAVE_ADDR 0x1C // with pins SA0=0, SA1=1
#define FXOS8700CQ_SLAVE_ADDR 0x1F   // with pins SA0=1, SA1=1

#define FXOS8700CQ_MCP_SLAVE_ADDR  0x1C   // MCP - Meta Carpal Phalangeal
#define FXOS8700CQ_PIP_SLAVE_ADDR  0x1D   // PIP - Proximal Inter Phalangeal
#define FXOS8700CQ_DIP_SLAVE_ADDR  0x1F   // DIP - Distal Inter Phalangeal

// Number of bytes to be read from the FXOS8700CQ at once
#define FXOS8700CQ_READ_LEN 12   // status plus 6 channels = 13 bytes

#define MAGSCALE27  27.3
#define MAGSCALE10  10.0
#define ACCELSCALE  4.88e-4

// Local Vancouver inclination and declination -
#define LOCALINCLINATION 70.367
#define LOCALDECLINATION 16.777

// Local field strength
#define LOCALHNT  18.379
#define LOCALVNT  51.579
#define LOCALFIELDSTRENGTH 54.699
#define LOCALFIELDX  17.596
#define LOCALFIELDY  5.305

// FXOS8700 Register definitions
#define  FXOS8700_STATUS          0x00
#define  FXOS8700_OUT_X_MSB       0x01
#define  FXOS8700_OUT_X_LSB       0x02
#define  FXOS8700_OUT_Y_MSB       0x03
#define  FXOS8700_OUT_Y_LSB       0x04
#define  FXOS8700_OUT_Z_MSB       0x05
#define  FXOS8700_OUT_Z_LSB       0x06
#define  FXOS8700_F_SETUP         0x09
#define  FXOS8700_TRIG_CFG        0x0A
#define  FXOS8700_SYSMOD          0x0B
#define  FXOS8700_INT_SOURCE      0x0C
#define  FXOS8700_WHO_AM_I        0x0D
#define  FXOS8700_XYZ_DATA_CFG    0x0E
#define  FXOS8700_HP_FILTER_CUTOFF 0x0F
#define  FXOS8700_PL_STATUS       0x10
#define  FXOS8700_PL_CFG          0x11
#define  FXOS8700_PL_COUNT        0x12
#define  FXOS8700_PL_BF_ZCOMP     0x13
#define  FXOS8700_PL_THS_REG      0x14
#define  FXOS8700_A_FFMT_CFG      0x15
#define  FXOS8700_A_FFMT_SRC      0x16
#define  FXOS8700_A_FFMT_THS      0x17
#define  FXOS8700_A_FFMT_COUNT    0x18
#define  FXOS8700_TRANSIENT_CFG   0x1D
#define  FXOS8700_TRANSIENT_SRC   0x1E
#define  FXOS8700_TRANSIENT_THS   0x1F
#define  FXOS8700_TRANSIENT_COUNT 0x20
#define  FXOS8700_PULSE_CFG       0x21
#define  FXOS8700_PULSE_SRC       0x22
#define  FXOS8700_PULSE_THSX      0x23
#define  FXOS8700_PULSE_THSY      0x24
#define  FXOS8700_PULSE_THSZ      0x25
#define  FXOS8700_PULSE_TMLT      0x26
#define  FXOS8700_PULSE_LTCY      0x27
#define  FXOS8700_PULSE_WIND      0x28
#define  FXOS8700_ASLP_COUNT      0x29
#define  FXOS8700_CTRL_REG1       0x2A
#define  FXOS8700_CTRL_REG2       0x2B
#define  FXOS8700_CTRL_REG3       0x2C
#define  FXOS8700_CTRL_REG4       0x2D
#define  FXOS8700_CTRL_REG5       0x2E
#define  FXOS8700_OFF_X           0x2F
#define  FXOS8700_OFF_Y           0x30
#define  FXOS8700_OFF_Z           0x31
#define  FXOS8700_M_DR_STATUS     0x32
#define  FXOS8700_M_OUT_X_MSB     0x33
#define  FXOS8700_M_OUT_X_LSB     0x34
#define  FXOS8700_M_OUT_Y_MSB     0x35
#define  FXOS8700_M_OUT_Y_LSB     0x36
#define  FXOS8700_M_OUT_Z_MSB     0x37
#define  FXOS8700_M_OUT_Z_LSB     0x38
#define  FXOS8700_CMP_OUT_X_MSB   0x39
#define  FXOS8700_CMP_OUT_X_LSB   0x3A
#define  FXOS8700_CMP_OUT_Y_MSB   0x3B
#define  FXOS8700_CMP_OUT_Y_LSB   0x3C
#define  FXOS8700_CMP_OUT_Z_MSB   0x3D
#define  FXOS8700_CMP_OUT_Z_LSB   0x3E
#define  FXOS8700_M_OFF_X_MSB     0x3F
#define  FXOS8700_M_OFF_X_LSB     0x40
#define  FXOS8700_M_OFF_Y_MSB     0x41
#define  FXOS8700_M_OFF_Y_LSB     0x42
#define  FXOS8700_M_OFF_Z_MSB     0x43
#define  FXOS8700_M_OFF_Z_LSB     0x44
#define  FXOS8700_MAX_X_MSB       0x45
#define  FXOS8700_MAX_X_LSB       0x46
#define  FXOS8700_MAX_Y_MSB       0x47
#define  FXOS8700_MAX_Y_LSB       0x48
#define  FXOS8700_MAX_Z_MSB       0x49
#define  FXOS8700_MAX_Z_LSB       0x4A
#define  FXOS8700_MIN_X_MSB       0x4B
#define  FXOS8700_MIN_X_LSB       0x4C
#define  FXOS8700_MIN_Y_MSB       0x4D
#define  FXOS8700_MIN_Y_LSB       0x4E
#define  FXOS8700_MIN_Z_MSB       0x4F
#define  FXOS8700_MIN_Z_LSB       0x50
#define  FXOS8700_TEMP            0x51
#define  FXOS8700_M_THS_CFG       0x52
#define  FXOS8700_M_THS_SRC       0x53
#define  FXOS8700_M_THS_X_MSB     0x54
#define  FXOS8700_M_THS_X_LSB     0x55
#define  FXOS8700_M_THS_Y_MSB     0x56
#define  FXOS8700_M_THS_Y_LSB     0x57
#define  FXOS8700_M_THS_Z_MSB     0x58
#define  FXOS8700_M_THS_Z_LSB     0x59
#define  FXOS8700_M_THS_COUNT     0x5A
#define  FXOS8700_M_CTRL_REG1     0x5B
#define  FXOS8700_M_CTRL_REG2     0x5C
#define  FXOS8700_M_CTRL_REG3     0x5D
#define  FXOS8700_M_INT_SRC       0x5E
#define  FXOS8700_A_VECM_CFG      0x5F
#define  FXOS8700_A_VECM_THS_MSB  0x60
#define  FXOS8700_A_VECM_THS_LSB  0x61
#define  FXOS8700_A_VECM_CNT      0x62
#define  FXOS8700_A_VECM_INITX_MSB 0x63
#define  FXOS8700_A_VECM_INITX_LSB 0x64
#define  FXOS8700_A_VECM_INITY_MSB 0x65
#define  FXOS8700_A_VECM_INITY_LSB 0x66
#define  FXOS8700_A_VECM_INITZ_MSB 0x67
#define  FXOS8700_A_VECM_INITZ_LSB 0x68
#define  FXOS8700_M_VECM_CFG      0x69
#define  FXOS8700_M_VECM_THS_MSB  0x6A
#define  FXOS8700_M_VECM_THS_LSB  0x6B
#define  FXOS8700_M_VECM_CNT      0x6C
#define  FXOS8700_M_VECM_INITX_MSB 0x6D
#define  FXOS8700_M_VECM_INITX_LSB 0x6E
#define  FXOS8700_M_VECM_INITY_MSB 0x6F
#define  FXOS8700_M_VECM_INITY_LSB 0x70
#define  FXOS8700_M_VECM_INITZ_MSB 0x71
#define  FXOS8700_M_VECM_INITZ_LSB 0x72
#define  FXOS8700_A_FFMT_THS_X_MSB 0x73
#define  FXOS8700_A_FFMT_THS_X_LSB 0x74
#define  FXOS8700_A_FFMT_THS_Y_MSB 0x75
#define  FXOS8700_A_FFMT_THS_Y_LSB 0x76
#define  FXOS8700_A_FFMT_THS_Z_MSB 0x77
#define  FXOS8700_A_FFMT_THS_Z_LSB 0x78

// PCA9545 Parameters - I2C mux on PicoM305
#define PCA9545_SLAVE_ADDRESS  0x70  // PCA9545A - different if PCA9545B or C

#define PCA9545_NOCHANNEL      0x00
#define PCA9545_CHANNEL_0      0x01
#define PCA9545_CHANNEL_1      0x02
#define PCA9545_CHANNEL_2      0x04
#define PCA9545_CHANNEL_3      0x08
